@@ -2,7 +2,11 @@ import json
 import os
 import shutil
 import tempfile
-from time import mktime, time
+from contextlib import suppress
+from datetime import datetime
+from pathlib import Path
+from time import time
+from typing import Any, Dict, Optional, Union
 
 from streamlink.compat import is_win32
 
@@ -11,27 +15,31 @@ if is_win32:
 else:
     xdg_cache = os.environ.get("XDG_CACHE_HOME", os.path.expanduser("~/.cache"))
 
-cache_dir = os.path.join(xdg_cache, "streamlink")
+# TODO: fix macOS path and deprecate old one (with fallback logic)
+CACHE_DIR = Path(xdg_cache) / "streamlink"
 
 
+# TODO: rewrite data structure
+#  - replace prefix logic with namespaces
+#  - change timestamps from (timezoned) epoch values to ISO8601 strings (UTC)
+#  - add JSON schema information
+#  - add translation logic, to keep backwards compatibility
 class Cache:
     """Caches Python values as JSON and prunes expired entries."""
 
-    def __init__(self, filename, key_prefix=""):
+    def __init__(self, filename: Union[str, Path], key_prefix: str = ""):
         self.key_prefix = key_prefix
-        self.filename = os.path.join(cache_dir, filename)
+        self.filename = CACHE_DIR / Path(filename)
 
-        self._cache = {}
+        self._cache: Dict[str, Dict[str, Any]] = {}
 
     def _load(self):
-        if os.path.exists(self.filename):
-            try:
-                with open(self.filename, "r") as fd:
-                    self._cache = json.load(fd)
-            except Exception:
-                self._cache = {}
-        else:
-            self._cache = {}
+        self._cache = {}
+        if self.filename.exists():
+            with suppress(Exception):
+                with self.filename.open("r") as fd:
+                    data = json.load(fd)
+                    self._cache.update(**data)
 
     def _prune(self):
         now = time()
@@ -50,44 +58,47 @@ class Cache:
     def _save(self):
         fd, tempname = tempfile.mkstemp()
         fd = os.fdopen(fd, "w")
-        json.dump(self._cache, fd, indent=2, separators=(",", ": "))
-        fd.close()
+        try:
+            json.dump(self._cache, fd, indent=2, separators=(",", ": "))
+        except Exception:
+            raise
+        finally:
+            fd.close()
 
         # Silently ignore errors
         try:
-            if not os.path.exists(os.path.dirname(self.filename)):
-                os.makedirs(os.path.dirname(self.filename))
-
-            shutil.move(tempname, self.filename)
+            self.filename.parent.mkdir(exist_ok=True, parents=True)
+            shutil.move(tempname, str(self.filename))
         except OSError:
-            os.remove(tempname)
+            with suppress(Exception):
+                os.remove(tempname)
 
-    def set(self, key, value, expires=60 * 60 * 24 * 7, expires_at=None):
+    def set(self, key: str, value: Any, expires: float = 60 * 60 * 24 * 7, expires_at: Optional[datetime] = None):
         self._load()
         self._prune()
 
         if self.key_prefix:
-            key = "{0}:{1}".format(self.key_prefix, key)
+            key = f"{self.key_prefix}:{key}"
 
         if expires_at is None:
             expires += time()
         else:
             try:
-                expires = mktime(expires_at.timetuple())
+                expires = expires_at.timestamp()
             except OverflowError:
                 expires = 0
 
         self._cache[key] = dict(value=value, expires=expires)
         self._save()
 
-    def get(self, key, default=None):
+    def get(self, key: str, default: Optional[Any] = None):
         self._load()
 
         if self._prune():
             self._save()
 
         if self.key_prefix:
-            key = "{0}:{1}".format(self.key_prefix, key)
+            key = f"{self.key_prefix}:{key}"
 
         if key in self._cache and "value" in self._cache[key]:
             return self._cache[key]["value"]
