@@ -1,9 +1,17 @@
 from streamlink.exceptions import PluginError
 from streamlink.options import Argument as PluginArgument, Arguments as PluginArguments, Options as PluginOptions
-from streamlink.plugin.plugin import HIGH_PRIORITY, LOW_PRIORITY, NORMAL_PRIORITY, NO_PRIORITY, Plugin, pluginmatcher
+from streamlink.plugin.plugin import (
+    HIGH_PRIORITY,
+    LOW_PRIORITY,
+    NORMAL_PRIORITY,
+    NO_PRIORITY,
+    Plugin,
+    pluginargument,
+    pluginmatcher,
+)
 
 __all__ = [
     "HIGH_PRIORITY", "NORMAL_PRIORITY", "LOW_PRIORITY", "NO_PRIORITY",
     "Plugin", "PluginArguments", "PluginArgument", "PluginError", "PluginOptions",
-    "pluginmatcher",
+    "pluginmatcher", "pluginargument",
 ]
