@@ -1,3 +1,10 @@
+"""
+$description Global live streaming platform for live video game broadcasts and individual live streams.
+$url live.bigo.tv
+$url bigoweb.co
+$type live
+"""
+
 import re
 
 from streamlink.plugin import Plugin, pluginmatcher
