@@ -1,10 +1,11 @@
 """
 $description Turkish live TV channels from Ciner Group, including Haberturk TV and Show TV.
-$url showtv.com.tr
+$url bloomberght.com
 $url haberturk.com
 $url haberturk.tv
 $url showmax.com.tr
 $url showturk.com.tr
+$url showtv.com.tr
 $type live
 """
 
@@ -18,19 +19,34 @@ from streamlink.stream.hls import HLSStream
 @pluginmatcher(re.compile(r"""
     https?://(?:www\.)?
     (?:
-        showtv\.com\.tr/canli-yayin(/showtv)?
+        bloomberght\.com/tv
         |
         haberturk\.(?:com|tv)(?:/tv)?/canliyayin
         |
-        showmax\.com\.tr/canliyayin
+        showmax\.com\.tr/canli-?yayin
         |
-        showturk\.com\.tr/canli-yayin/showturk
+        showturk\.com\.tr/canli-?yayin(?:/showtv)?
+        |
+        showtv\.com\.tr/canli-yayin(?:/showtv)?
     )/?
 """, re.VERBOSE))
 class CinerGroup(Plugin):
-    def _get_streams(self):
-        stream_url = self.session.http.get(self.url, schema=validate.Schema(
-            validate.parse_html(),
+    @staticmethod
+    def _schema_videourl():
+        return validate.Schema(
+            validate.xml_xpath_string(".//script[contains(text(), 'videoUrl')]/text()"),
+            validate.none_or_all(
+                re.compile(r"""(?<!//)\s*var\s+videoUrl\s*=\s*(?P<q>['"])(?P<url>.+?)(?P=q)"""),
+                validate.none_or_all(
+                    validate.get("url"),
+                    validate.url(),
+                ),
+            ),
+        )
+
+    @staticmethod
+    def _schema_data_ht():
+        return validate.Schema(
             validate.xml_xpath_string(".//div[@data-ht][1]/@data-ht"),
             validate.none_or_all(
                 validate.parse_json(),
@@ -39,7 +55,13 @@ class CinerGroup(Plugin):
                 },
                 validate.get("ht_stream_m3u8"),
             ),
-        ))
+        )
+
+    def _get_streams(self):
+        root = self.session.http.get(self.url, schema=validate.Schema(validate.parse_html()))
+        schema_getters = self._schema_videourl, self._schema_data_ht
+        stream_url = next(filter(lambda res: res, map(lambda get_schema: get_schema().validate(root), schema_getters)), None)
+
         if stream_url:
             return HLSStream.parse_variant_playlist(self.session, stream_url)
 
