@@ -2,7 +2,7 @@ import logging
 import re
 
 from streamlink.plugin import Plugin, pluginmatcher
-from streamlink.plugin.plugin import LOW_PRIORITY, stream_weight
+from streamlink.plugin.plugin import LOW_PRIORITY, parse_params, stream_weight
 from streamlink.stream.dash import DASHStream
 from streamlink.utils.url import update_scheme
 
@@ -10,10 +10,10 @@ log = logging.getLogger(__name__)
 
 
 @pluginmatcher(re.compile(
-    r"dash://(?P<url>.+)"
+    r"dash://(?P<url>\S+)(?:\s(?P<params>.+))?"
 ))
 @pluginmatcher(priority=LOW_PRIORITY, pattern=re.compile(
-    r"(?P<url>.+\.mpd(?:\?.*)?)"
+    r"(?P<url>\S+\.mpd(?:\?\S*)?)(?:\s(?P<params>.+))?"
 ))
 class MPEGDASH(Plugin):
     @classmethod
@@ -24,15 +24,17 @@ class MPEGDASH(Plugin):
             weight += int(match.group(2))
             return weight, group
         elif match and match.group(2):
-            return stream_weight(match.group(2) + 'k')
+            return stream_weight(f"{match.group(2)}k")
         else:
             return stream_weight(stream)
 
     def _get_streams(self):
-        url = update_scheme("https://", self.match.group(1), force=False)
-        log.debug(f"Parsing MPD URL: {url}")
+        data = self.match.groupdict()
+        url = update_scheme("https://", data.get("url"), force=False)
+        params = parse_params(data.get("params"))
+        log.debug(f"URL={url}; params={params}")
 
-        return DASHStream.parse_manifest(self.session, url)
+        return DASHStream.parse_manifest(self.session, url, **params)
 
 
 __plugin__ = MPEGDASH
