@@ -1,3 +1,10 @@
+"""
+$description Stream videos stored in Google Drive.
+$url docs.google.com
+$url drive.google.com
+$type vod
+"""
+
 import logging
 import re
 from urllib.parse import parse_qsl
