@@ -1,5 +1,5 @@
 """
-$description Japanese live streaming and video hosting social platform.
+$description Japanese live-streaming and video hosting social platform.
 $url live.nicovideo.jp
 $type live, vod
 $account Required by some streams
@@ -11,8 +11,7 @@ import re
 from threading import Event
 from urllib.parse import urljoin
 
-from streamlink.exceptions import FatalPluginError
-from streamlink.plugin import Plugin, PluginArgument, PluginArguments, PluginError, pluginmatcher
+from streamlink.plugin import Plugin, PluginError, pluginargument, pluginmatcher
 from streamlink.plugin.api import useragents, validate
 from streamlink.plugin.api.websocket import WebsocketClient
 from streamlink.stream.hls import HLSStream, HLSStreamReader
@@ -117,50 +116,50 @@ class NicoLiveHLSStream(HLSStream):
 @pluginmatcher(re.compile(
     r"https?://(?P<domain>live\d*\.nicovideo\.jp)/watch/(lv|co)\d+"
 ))
+@pluginargument(
+    "email",
+    sensitive=True,
+    argument_name="niconico-email",
+    metavar="EMAIL",
+    help="The email or phone number associated with your Niconico account",
+)
+@pluginargument(
+    "password",
+    sensitive=True,
+    argument_name="niconico-password",
+    metavar="PASSWORD",
+    help="The password of your Niconico account",
+)
+@pluginargument(
+    "user-session",
+    sensitive=True,
+    argument_name="niconico-user-session",
+    metavar="VALUE",
+    help="""
+        Value of the user-session token.
+
+        Can be used as an alternative to providing a password.
+    """,
+)
+@pluginargument(
+    "purge-credentials",
+    argument_name="niconico-purge-credentials",
+    action="store_true",
+    help="Purge cached Niconico credentials to initiate a new session and reauthenticate.",
+)
+@pluginargument(
+    "timeshift-offset",
+    type=hours_minutes_seconds,
+    argument_name="niconico-timeshift-offset",
+    metavar="[HH:]MM:SS",
+    default=None,
+    help="""
+        Amount of time to skip from the beginning of a stream.
+
+        Default is 00:00:00.
+    """,
+)
 class NicoLive(Plugin):
-    arguments = PluginArguments(
-        PluginArgument(
-            "email",
-            argument_name="niconico-email",
-            sensitive=True,
-            metavar="EMAIL",
-            help="The email or phone number associated with your Niconico account"
-        ),
-        PluginArgument(
-            "password",
-            argument_name="niconico-password",
-            sensitive=True,
-            metavar="PASSWORD",
-            help="The password of your Niconico account"
-        ),
-        PluginArgument(
-            "user-session",
-            argument_name="niconico-user-session",
-            sensitive=True,
-            metavar="VALUE",
-            help="Value of the user-session token \n(can be used in "
-                 "case you do not want to put your password here)"
-        ),
-        PluginArgument(
-            "purge-credentials",
-            argument_name="niconico-purge-credentials",
-            action="store_true",
-            help="Purge cached Niconico credentials to initiate a new session and reauthenticate."
-        ),
-        PluginArgument(
-            "timeshift-offset",
-            type=hours_minutes_seconds,
-            argument_name="niconico-timeshift-offset",
-            metavar="[HH:]MM:SS",
-            default=None,
-            help="""
-            Amount of time to skip from the beginning of a stream.
-
-            Default is 00:00:00.
-            """
-        )
-    )
-
     STREAM_READY_TIMEOUT = 6
     LOGIN_URL = "https://account.nicovideo.jp/login/redirector"
     LOGIN_URL_PARAMS = {
@@ -276,19 +275,15 @@ class NicoLive(Plugin):
             for elem in root.xpath(".//form[@action]//input"):
                 if elem.attrib.get("value"):
                     input_with_value[elem.attrib.get("name")] = elem.attrib.get("value")
+                elif elem.attrib.get("id") == "oneTimePw":
+                    maxlength = int(elem.attrib.get("maxlength"))
+                    oneTimePw = self.input_ask("Enter the 6 digit number included in email")
+                    if len(oneTimePw) > maxlength:
+                        log.error("invalid user input")
+                        return
+                    input_with_value[elem.attrib.get("name")] = oneTimePw
                 else:
-                    if elem.attrib.get("id") == "oneTimePw":
-                        maxlength = int(elem.attrib.get("maxlength"))
-                        try:
-                            oneTimePw = self.input_ask("Enter the 6 digit number included in email")
-                            if len(oneTimePw) > maxlength:
-                                log.error("invalid user input")
-                                return
-                        except FatalPluginError:
-                            return
-                        input_with_value[elem.attrib.get("name")] = oneTimePw
-                    else:
-                        log.debug(f"unknown input: {elem.attrib.get('name')}")
+                    log.debug(f"unknown input: {elem.attrib.get('name')}")
 
             root = self.session.http.post(
                 urljoin("https://account.nicovideo.jp", root.xpath("string(.//form[@action]/@action)")),
