@@ -1,3 +1,10 @@
+"""
+$description Live TV channels and video on-demand service from NOS, a Dutch public, state-owned broadcaster.
+$url nos.nl
+$type live, vod
+$region Netherlands
+"""
+
 import logging
 import re
 
