@@ -1,3 +1,11 @@
+"""
+$description Live TV channels and video on-demand service from NRK, a Norwegian public, state-owned broadcaster.
+$url tv.nrk.no
+$url radio.nrk.no
+$type live, vod
+$region Norway
+"""
+
 import logging
 import re
 from urllib.parse import urljoin
