@@ -1,14 +1,15 @@
 """
-$description Russian live streaming and video hosting social platform.
+$description Russian live-streaming and video hosting social platform.
 $url ok.ru
+$url mobile.ok.ru
 $type live, vod
 """
 
 import logging
 import re
-from urllib.parse import unquote
+from urllib.parse import unquote, urlparse
 
-from streamlink.plugin import Plugin, PluginError, pluginmatcher
+from streamlink.plugin import Plugin, pluginmatcher
 from streamlink.plugin.api import validate
 from streamlink.stream.dash import DASHStream
 from streamlink.stream.hls import HLSStream
@@ -17,9 +18,8 @@ from streamlink.stream.http import HTTPStream
 log = logging.getLogger(__name__)
 
 
-@pluginmatcher(re.compile(
-    r'https?://(?:www\.)?ok\.ru/'
-))
+@pluginmatcher(re.compile(r"https?://(?:www\.)?ok\.ru/"))
+@pluginmatcher(re.compile(r"https?://m(?:obile)?\.ok\.ru/"))
 class OKru(Plugin):
     QUALITY_WEIGHTS = {
         "full": 1080,
@@ -42,7 +42,38 @@ class OKru(Plugin):
 
         return super().stream_weight(key)
 
-    def _get_streams(self):
+    def _get_streams_mobile(self):
+        data = self.session.http.get(self.url, schema=validate.Schema(
+            validate.parse_html(),
+            validate.xml_find(".//a[@data-video]"),
+            validate.get("data-video"),
+            validate.none_or_all(
+                str,
+                validate.parse_json(),
+                {
+                    "videoName": str,
+                    "videoSrc": validate.url(),
+                    "movieId": str,
+                },
+                validate.union_get("movieId", "videoName", "videoSrc"),
+            ),
+        ))
+        if not data:
+            return
+
+        self.id, self.title, url = data
+
+        stream_url = self.session.http.head(url).headers.get("Location")
+        if not stream_url:
+            return
+
+        return (
+            HLSStream.parse_variant_playlist(self.session, stream_url)
+            if urlparse(stream_url).path.endswith(".m3u8") else
+            {"vod": HTTPStream(self.session, stream_url)}
+        )
+
+    def _get_streams_default(self):
         schema_metadata = validate.Schema(
             validate.parse_json(),
             {
@@ -54,32 +85,28 @@ class OKru(Plugin):
                 validate.optional("videos"): [validate.all(
                     {
                         "name": str,
-                        "url": validate.url()
+                        "url": validate.url(),
                     },
-                    validate.union_get("name", "url")
-                )]
-            }
+                    validate.union_get("name", "url"),
+                )],
+            },
         )
 
-        try:
-            metadata, metadata_url = self.session.http.get(self.url, schema=validate.Schema(
-                validate.parse_html(),
-                validate.xml_find(".//*[@data-options]"),
-                validate.get("data-options"),
-                validate.parse_json(),
-                {"flashvars": {
-                    validate.optional("metadata"): str,
-                    validate.optional("metadataUrl"): validate.all(
-                        validate.transform(unquote),
-                        validate.url()
-                    )
-                }},
-                validate.get("flashvars"),
-                validate.union_get("metadata", "metadataUrl")
-            ))
-        except PluginError:
-            log.error("Could not find metadata")
-            return
+        metadata, metadata_url = self.session.http.get(self.url, schema=validate.Schema(
+            validate.parse_html(),
+            validate.xml_find(".//*[@data-options]"),
+            validate.get("data-options"),
+            validate.parse_json(),
+            {"flashvars": {
+                validate.optional("metadata"): str,
+                validate.optional("metadataUrl"): validate.all(
+                    validate.transform(unquote),
+                    validate.url(),
+                ),
+            }},
+            validate.get("flashvars"),
+            validate.union_get("metadata", "metadataUrl"),
+        ))
 
         self.session.http.headers.update({"Referer": self.url})
 
@@ -88,11 +115,7 @@ class OKru(Plugin):
 
         log.trace(f"{metadata!r}")
 
-        try:
-            data = schema_metadata.validate(metadata)
-        except PluginError:
-            log.error("Could not parse metadata")
-            return
+        data = schema_metadata.validate(metadata)
 
         self.author = data.get("author")
         self.title = data.get("movie")
@@ -109,5 +132,8 @@ class OKru(Plugin):
             for name, url in data.get("videos", [])
         }
 
+    def _get_streams(self):
+        return self._get_streams_default() if self.matches[0] else self._get_streams_mobile()
+
 
 __plugin__ = OKru
