@@ -1,5 +1,5 @@
 """
-$description South Korean live streaming platform for individual live streams.
+$description South Korean live-streaming platform for individual live streams.
 $url pandalive.co.kr
 $type live
 """
@@ -19,10 +19,9 @@ log = logging.getLogger(__name__)
 ))
 class Pandalive(Plugin):
     def _get_streams(self):
-        re_media_code = re.compile(r"""routePath:\s*(["'])(\\u002F|/)live(\\u002F|/)play(\\u002F|/)(?P<id>\d+)\1""")
         media_code = self.session.http.get(self.url, schema=validate.Schema(
-            validate.transform(re_media_code.search),
-            validate.any(None, validate.get("id"))
+            re.compile(r"""routePath:\s*(?P<q>["'])(\\u002F|/)live(\\u002F|/)play(\\u002F|/)(?P<id>.+?)(?P=q)"""),
+            validate.any(None, validate.get("id")),
         ))
 
         if not media_code:
@@ -34,34 +33,40 @@ class Pandalive(Plugin):
             "https://api.pandalive.co.kr/v1/live/play",
             data={
                 "action": "watch",
-                "userIdx": media_code
+                "userId": media_code,
             },
             schema=validate.Schema(
                 validate.parse_json(),
-                {
-                    "media": {
-                        "title": str,
-                        "userId": str,
-                        "userNick": str,
-                        "isPw": bool,
-                        "isLive": bool,
-                        "liveType": str,
+                validate.any(
+                    {
+                        "media": {
+                            "title": str,
+                            "userId": str,
+                            "userNick": str,
+                            "isPw": bool,
+                            "isLive": bool,
+                            "liveType": str,
+                        },
+                        "PlayList": {
+                            validate.optional("hls"): [{
+                                "url": validate.url(),
+                            }],
+                            validate.optional("hls2"): [{
+                                "url": validate.url(),
+                            }],
+                            validate.optional("hls3"): [{
+                                "url": validate.url(),
+                            }],
+                        },
+                        "result": bool,
+                        "message": str,
                     },
-                    "PlayList": {
-                        validate.optional("hls"): [{
-                            "url": validate.url(),
-                        }],
-                        validate.optional("hls2"): [{
-                            "url": validate.url(),
-                        }],
-                        validate.optional("hls3"): [{
-                            "url": validate.url(),
-                        }],
+                    {
+                        "result": bool,
+                        "message": str,
                     },
-                    "result": bool,
-                    "message": str,
-                }
-            )
+                ),
+            ),
         )
 
         if not json["result"]:
