@@ -1,3 +1,9 @@
+"""
+$description Sporting channel live stream owned by Sportal, a Bulgarian sports media website.
+$url sportal.bg
+$type live
+"""
+
 import logging
 import re
 
