@@ -1,3 +1,10 @@
+"""
+$description German news and documentaries TV channel, owned by Axel Springer SE.
+$url welt.de
+$type live, vod
+$region Germany
+"""
+
 import re
 from urllib.parse import quote
 
