@@ -1,5 +1,5 @@
 """
-$description Global live streaming and video hosting social platform owned by Google.
+$description Global live-streaming and video hosting social platform owned by Google.
 $url youtube.com
 $url youtu.be
 $type live, vod
@@ -9,7 +9,6 @@ $notes Protected videos are not supported
 import json
 import logging
 import re
-from html import unescape
 from urllib.parse import urlparse, urlunparse
 
 from streamlink.plugin import Plugin, PluginError, pluginmatcher
@@ -45,8 +44,7 @@ log = logging.getLogger(__name__)
 """, re.VERBOSE))
 class YouTube(Plugin):
     _re_ytInitialData = re.compile(r"""var\s+ytInitialData\s*=\s*({.*?})\s*;\s*</script>""", re.DOTALL)
-    _re_ytInitialPlayerResponse = re.compile(r"""var\s+ytInitialPlayerResponse\s*=\s*({.*?});\s*var\s+meta\s*=""", re.DOTALL)
-    _re_mime_type = re.compile(r"""^(?P<type>\w+)/(?P<container>\w+); codecs="(?P<codecs>.+)"$""")
+    _re_ytInitialPlayerResponse = re.compile(r"""var\s+ytInitialPlayerResponse\s*=\s*({.*?});\s*var\s+\w+\s*=""", re.DOTALL)
 
     _url_canonical = "https://www.youtube.com/watch?v={video_id}"
     _url_channelid_live = "https://www.youtube.com/channel/{channel_id}/live"
@@ -76,9 +74,9 @@ class YouTube(Plugin):
         258: 258,
     }
 
-    def __init__(self, url):
-        super().__init__(url)
-        parsed = urlparse(url)
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        parsed = urlparse(self.url)
 
         # translate input URLs to be able to find embedded data and to avoid unnecessary HTTP redirects
         if parsed.netloc == "gaming.youtube.com":
@@ -115,7 +113,18 @@ class YouTube(Plugin):
     def _schema_consent(data):
         schema_consent = validate.Schema(
             validate.parse_html(),
-            validate.xml_findall(".//input[@type='hidden']")
+            validate.any(
+                validate.xml_find(".//form[@action='https://consent.youtube.com/s']"),
+                validate.all(
+                    validate.xml_xpath(".//form[@action='https://consent.youtube.com/save']"),
+                    validate.filter(lambda elem: elem.xpath(".//input[@type='hidden'][@name='set_ytc'][@value='true']")),
+                    validate.get(0),
+                )
+            ),
+            validate.union((
+                validate.get("action"),
+                validate.xml_xpath(".//input[@type='hidden']"),
+            )),
         )
         return schema_consent.validate(data)
 
@@ -138,7 +147,7 @@ class YouTube(Plugin):
             validate.get("playabilityStatus"),
             validate.union_get("status", "reason")
         )
-        return validate.validate(schema, data)
+        return schema.validate(data)
 
     @classmethod
     def _schema_videodetails(cls, data):
@@ -178,7 +187,7 @@ class YouTube(Plugin):
                 ("videoDetails", "isLive")
             )
         )
-        videoDetails = validate.validate(schema, data)
+        videoDetails = schema.validate(data)
         log.trace(f"videoDetails = {videoDetails!r}")
         return videoDetails
 
@@ -200,7 +209,7 @@ class YouTube(Plugin):
                         "itag": int,
                         "mimeType": validate.all(
                             str,
-                            validate.transform(cls._re_mime_type.search),
+                            validate.regex(re.compile(r"""^(?P<type>\w+)/(?P<container>\w+); codecs="(?P<codecs>.+)"$""")),
                             validate.union_get("type", "codecs"),
                         ),
                         validate.optional("url"): validate.url(scheme="http"),
@@ -212,7 +221,7 @@ class YouTube(Plugin):
             validate.get("streamingData"),
             validate.union_get("hlsManifestUrl", "formats", "adaptiveFormats")
         )
-        hls_manifest, formats, adaptive_formats = validate.validate(schema, data)
+        hls_manifest, formats, adaptive_formats = schema.validate(data)
         return hls_manifest, formats or [], adaptive_formats or []
 
     def _create_adaptive_streams(self, adaptive_formats):
@@ -253,12 +262,14 @@ class YouTube(Plugin):
     def _get_res(self, url):
         res = self.session.http.get(url)
         if urlparse(res.url).netloc == "consent.youtube.com":
+            target, elems = self._schema_consent(res.text)
             c_data = {
-                elem.attrib.get("name"): unescape(elem.attrib.get("value"))
-                for elem in self._schema_consent(res.text)
+                elem.attrib.get("name"): elem.attrib.get("value")
+                for elem in elems
             }
-            log.debug(f"c_data_keys: {', '.join(c_data.keys())}")
-            res = self.session.http.post("https://consent.youtube.com/s", data=c_data)
+            log.debug(f"consent target: {target}")
+            log.debug(f"consent data: {', '.join(c_data.keys())}")
+            res = self.session.http.post(target, data=c_data)
         return res
 
     @staticmethod
