@@ -1,8 +1,15 @@
+"""
+$description Indian live TV channels and video on-demand service. OTT service from YuppTV.
+$url yupptv.com
+$type live, vod
+$account Some streams require an account and subscription
+"""
+
 import logging
 import re
 import time
 
-from streamlink.plugin import Plugin, PluginArgument, PluginArguments, pluginmatcher
+from streamlink.plugin import Plugin, pluginargument, pluginmatcher
 from streamlink.plugin.api import useragents
 from streamlink.stream.hls import HLSStream
 
@@ -12,39 +19,30 @@ log = logging.getLogger(__name__)
 @pluginmatcher(re.compile(
     r'https?://(?:www\.)?yupptv\.com'
 ))
+@pluginargument(
+    "boxid",
+    requires=["yuppflixtoken"],
+    sensitive=True,
+    metavar="BOXID",
+    help="The yupptv.com boxid that's used in the BoxId cookie.",
+)
+@pluginargument(
+    "yuppflixtoken",
+    sensitive=True,
+    metavar="YUPPFLIXTOKEN",
+    help="The yupptv.com yuppflixtoken that's used in the YuppflixToken cookie.",
+)
+@pluginargument(
+    "purge-credentials",
+    action="store_true",
+    help="Purge cached YuppTV credentials to initiate a new session and reauthenticate.",
+)
 class YuppTV(Plugin):
     _m3u8_re = re.compile(r'''['"](http.+\.m3u8.*?)['"]''')
     _cookie_expiry = 3600 * 24 * 365
 
-    arguments = PluginArguments(
-        PluginArgument(
-            "boxid",
-            requires=["yuppflixtoken"],
-            sensitive=True,
-            metavar="BOXID",
-            help="""
-        The yupptv.com boxid that's used in the BoxId cookie.
-        Can be used instead of the username/password login process.
-        """),
-        PluginArgument(
-            "yuppflixtoken",
-            sensitive=True,
-            metavar="YUPPFLIXTOKEN",
-            help="""
-        The yupptv.com yuppflixtoken that's used in the YuppflixToken cookie.
-        Can be used instead of the username/password login process.
-        """),
-        PluginArgument(
-            "purge-credentials",
-            action="store_true",
-            help="""
-        Purge cached YuppTV credentials to initiate a new session
-        and reauthenticate.
-        """),
-    )
-
-    def __init__(self, url):
-        super().__init__(url)
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
         self._authed = (self.session.http.cookies.get("BoxId")
                         and self.session.http.cookies.get("YuppflixToken"))
 
@@ -87,7 +85,7 @@ class YuppTV(Plugin):
 
         if self._authed:
             log.debug("Attempting to authenticate using cached cookies")
-        elif not self._authed and login_box_id and login_yuppflix_token:
+        elif login_box_id and login_yuppflix_token:
             self._login_using_box_id_and_yuppflix_token(
                 login_box_id,
                 login_yuppflix_token,
