@@ -1,3 +1,9 @@
+"""
+$description Indian Hindi-language news channel covering world & Indian news, business, entertainment and sport.
+$url zeenews.india.com
+$type live
+"""
+
 import logging
 import re
 
