@@ -1,16 +1,15 @@
 import logging
 import pkgutil
+import warnings
 from functools import lru_cache
 from socket import AF_INET, AF_INET6
-from typing import Any, Dict, Optional, Tuple, Type
+from typing import Any, Callable, ClassVar, Dict, Iterator, Mapping, Optional, Tuple, Type
 
-# noinspection PyPackageRequirements
 import urllib3.util.connection as urllib3_util_connection
-# noinspection PyPackageRequirements
 import urllib3.util.ssl_ as urllib3_util_ssl
 
 from streamlink import __version__, plugins
-from streamlink.exceptions import NoPluginError, PluginError
+from streamlink.exceptions import NoPluginError, PluginError, StreamlinkDeprecationWarning
 from streamlink.logger import StreamlinkLogger
 from streamlink.options import Options
 from streamlink.plugin.api.http_session import HTTPSession
@@ -24,7 +23,6 @@ logging.setLoggerClass(StreamlinkLogger)
 log = logging.getLogger(__name__)
 
 
-# noinspection PyUnresolvedReferences
 _original_allowed_gai_family = urllib3_util_connection.allowed_gai_family  # type: ignore[attr-defined]
 
 
@@ -32,6 +30,152 @@ class PythonDeprecatedWarning(UserWarning):
     pass
 
 
+class StreamlinkOptions(Options):
+    _OPTIONS_HTTP_ATTRS = {
+        "http-cookies": "cookies",
+        "http-headers": "headers",
+        "http-query-params": "params",
+        "http-ssl-cert": "cert",
+        "http-ssl-trust-env": "trust_env",
+        "http-ssl-verify": "verify",
+        "http-timeout": "timeout",
+    }
+
+    def __init__(self, session: "Streamlink", *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.session = session
+
+    # ---- utils
+
+    @staticmethod
+    def _parse_key_equals_value_string(value: str) -> Iterator[Tuple[str, str]]:
+        for keyval in value.split(";"):
+            try:
+                key, val = keyval.split("=", 1)
+                yield key.strip(), val.strip()
+            except ValueError:
+                continue
+
+    # ---- getters
+
+    def _get_http_proxy(self, key):
+        if key == "https-proxy":
+            warnings.warn(
+                "The `https-proxy` option has been deprecated in favor of a single `http-proxy` option",
+                StreamlinkDeprecationWarning,
+            )
+        return self.session.http.proxies.get("https" if key == "https-proxy" else "http")
+
+    def _get_http_attr(self, key):
+        return getattr(self.session.http, self._OPTIONS_HTTP_ATTRS[key])
+
+    # ---- setters
+
+    def _set_interface(self, key, value):
+        for scheme, adapter in self.session.http.adapters.items():
+            if scheme not in ("http://", "https://"):
+                continue
+            if not value:
+                adapter.poolmanager.connection_pool_kw.pop("source_address")
+            else:
+                # https://docs.python.org/3/library/socket.html#socket.create_connection
+                adapter.poolmanager.connection_pool_kw.update(source_address=(value, 0))
+        self.set_explicit(key, None if not value else value)
+
+    def _set_ipv4_ipv6(self, key, value):
+        self.set_explicit(key, value)
+        if not value:
+            urllib3_util_connection.allowed_gai_family = _original_allowed_gai_family  # type: ignore[attr-defined]
+        elif key == "ipv4":
+            self.set_explicit("ipv6", False)
+            urllib3_util_connection.allowed_gai_family = (lambda: AF_INET)  # type: ignore[attr-defined]
+        else:
+            self.set_explicit("ipv4", False)
+            urllib3_util_connection.allowed_gai_family = (lambda: AF_INET6)  # type: ignore[attr-defined]
+
+    def _set_http_proxy(self, key, value):
+        self.session.http.proxies["http"] \
+            = self.session.http.proxies["https"] \
+            = update_scheme("https://", value, force=False)
+        if key == "https-proxy":
+            warnings.warn(
+                "The `https-proxy` option has been deprecated in favor of a single `http-proxy` option",
+                StreamlinkDeprecationWarning,
+            )
+
+    def _set_http_attr_key_equals_value(self, key, value):
+        getattr(self.session.http, self._OPTIONS_HTTP_ATTRS[key]).update(
+            value if isinstance(value, dict) else dict(self._parse_key_equals_value_string(value))
+        )
+
+    def _set_http_attr(self, key, value):
+        setattr(self.session.http, self._OPTIONS_HTTP_ATTRS[key], value)
+
+    def _set_http_disable_dh(self, key, value):
+        self.set_explicit(key, value)
+        default_ciphers = [
+            item
+            for item in urllib3_util_ssl.DEFAULT_CIPHERS.split(":")  # type: ignore[attr-defined]
+            if item != "!DH"
+        ]
+        if value:
+            default_ciphers.append("!DH")
+        urllib3_util_ssl.DEFAULT_CIPHERS = ":".join(default_ciphers)  # type: ignore[attr-defined]
+
+    @staticmethod
+    def _factory_set_deprecated(name: str, mapper: Callable[[Any], Any]) -> Callable[["StreamlinkOptions", str, Any], None]:
+        def inner(self: "StreamlinkOptions", key: str, value: Any) -> None:
+            self.set_explicit(name, mapper(value))
+            warnings.warn(
+                f"`{key}` has been deprecated in favor of the `{name}` option",
+                StreamlinkDeprecationWarning,
+            )
+
+        return inner
+
+    # bind explicitly with dummy context, to prevent `TypeError: 'staticmethod' object is not callable` on py<310
+    _factory_set_deprecated = _factory_set_deprecated.__get__(object)
+
+    # ----
+
+    _MAP_GETTERS: ClassVar[Mapping[str, Callable[["StreamlinkOptions", str], Any]]] = {
+        "http-proxy": _get_http_proxy,
+        "https-proxy": _get_http_proxy,
+        "http-cookies": _get_http_attr,
+        "http-headers": _get_http_attr,
+        "http-query-params": _get_http_attr,
+        "http-ssl-cert": _get_http_attr,
+        "http-ssl-verify": _get_http_attr,
+        "http-trust-env": _get_http_attr,
+        "http-timeout": _get_http_attr,
+    }
+
+    _MAP_SETTERS: ClassVar[Mapping[str, Callable[["StreamlinkOptions", str, Any], None]]] = {
+        "interface": _set_interface,
+        "ipv4": _set_ipv4_ipv6,
+        "ipv6": _set_ipv4_ipv6,
+        "http-proxy": _set_http_proxy,
+        "https-proxy": _set_http_proxy,
+        "http-cookies": _set_http_attr_key_equals_value,
+        "http-headers": _set_http_attr_key_equals_value,
+        "http-query-params": _set_http_attr_key_equals_value,
+        "http-disable-dh": _set_http_disable_dh,
+        "http-ssl-cert": _set_http_attr,
+        "http-ssl-verify": _set_http_attr,
+        "http-trust-env": _set_http_attr,
+        "http-timeout": _set_http_attr,
+        "dash-segment-attempts": _factory_set_deprecated("stream-segment-attempts", int),
+        "hls-segment-attempts": _factory_set_deprecated("stream-segment-attempts", int),
+        "dash-segment-threads": _factory_set_deprecated("stream-segment-threads", int),
+        "hls-segment-threads": _factory_set_deprecated("stream-segment-threads", int),
+        "dash-segment-timeout": _factory_set_deprecated("stream-segment-timeout", float),
+        "hls-segment-timeout": _factory_set_deprecated("stream-segment-timeout", float),
+        "dash-timeout": _factory_set_deprecated("stream-timeout", float),
+        "hls-timeout": _factory_set_deprecated("stream-timeout", float),
+        "http-stream-timeout": _factory_set_deprecated("stream-timeout", float),
+    }
+
+
 class Streamlink:
     """
     The Streamlink session is used to load and resolve plugins, and to store options used by plugins and stream implementations.
@@ -52,7 +196,7 @@ class Streamlink:
         """
 
         self.http = HTTPSession()
-        self.options = Options({
+        self.options = StreamlinkOptions(self, {
             "interface": None,
             "ipv4": False,
             "ipv6": False,
@@ -69,6 +213,7 @@ class Streamlink:
             "stream-segment-timeout": 10.0,
             "stream-timeout": 60.0,
             "ffmpeg-ffmpeg": None,
+            "ffmpeg-no-validation": False,
             "ffmpeg-fout": None,
             "ffmpeg-video-transcode": None,
             "ffmpeg-audio-transcode": None,
@@ -76,14 +221,14 @@ class Streamlink:
             "ffmpeg-start-at-zero": False,
             "mux-subtitles": False,
             "locale": None,
-            "user-input-requester": None
+            "user-input-requester": None,
         })
         if options:
             self.options.update(options)
         self.plugins: Dict[str, Type[Plugin]] = {}
         self.load_builtin_plugins()
 
-    def set_option(self, key: str, value: Any):
+    def set_option(self, key: str, value: Any) -> None:
         """
         Sets general options used by plugins and streams originating from this session object.
 
@@ -156,6 +301,9 @@ class Streamlink:
                                  ffmpeg executable use by Muxing streams
                                  e.g. ``/usr/local/bin/ffmpeg``
 
+        ffmpeg-no-validation     (bool) Disable FFmpeg validation and version logging.
+                                 default: ``False``
+
         ffmpeg-verbose           (bool) Log stderr from ffmpeg to the
                                  console
 
@@ -200,126 +348,21 @@ class Streamlink:
                                  default: ``system locale``.
 
         user-input-requester     (UserInputRequester) instance of UserInputRequester
-                                 to collect input from the user at runtime. Must be
-                                 set before the plugins are loaded.
-                                 default: ``UserInputRequester``.
+                                 to collect input from the user at runtime.
+                                 default: ``None``.
         ======================== =========================================
         """
 
-        if key == "interface":
-            for scheme, adapter in self.http.adapters.items():
-                if scheme not in ("http://", "https://"):
-                    continue
-                if not value:
-                    adapter.poolmanager.connection_pool_kw.pop("source_address")
-                else:
-                    adapter.poolmanager.connection_pool_kw.update(
-                        # https://docs.python.org/3/library/socket.html#socket.create_connection
-                        source_address=(value, 0)
-                    )
-            self.options.set(key, None if not value else value)
+        self.options.set(key, value)
 
-        elif key == "ipv4" or key == "ipv6":
-            self.options.set(key, value)
-            if not value:
-                urllib3_util_connection.allowed_gai_family = _original_allowed_gai_family  # type: ignore[attr-defined]
-            elif key == "ipv4":
-                self.options.set("ipv6", False)
-                urllib3_util_connection.allowed_gai_family = (lambda: AF_INET)  # type: ignore[attr-defined]
-            else:
-                self.options.set("ipv4", False)
-                urllib3_util_connection.allowed_gai_family = (lambda: AF_INET6)  # type: ignore[attr-defined]
-
-        elif key in ("http-proxy", "https-proxy"):
-            self.http.proxies["http"] = update_scheme("https://", value, force=False)
-            self.http.proxies["https"] = self.http.proxies["http"]
-            if key == "https-proxy":
-                log.info("The https-proxy option has been deprecated in favour of a single http-proxy option")
-
-        elif key == "http-cookies":
-            if isinstance(value, dict):
-                self.http.cookies.update(value)
-            else:
-                self.http.parse_cookies(value)
-
-        elif key == "http-headers":
-            if isinstance(value, dict):
-                self.http.headers.update(value)
-            else:
-                self.http.parse_headers(value)
-
-        elif key == "http-query-params":
-            if isinstance(value, dict):
-                self.http.params.update(value)
-            else:
-                self.http.parse_query_params(value)
-
-        elif key == "http-trust-env":
-            self.http.trust_env = value
-
-        elif key == "http-ssl-verify":
-            self.http.verify = value
-
-        elif key == "http-disable-dh":
-            default_ciphers = list(
-                item
-                for item in urllib3_util_ssl.DEFAULT_CIPHERS.split(":")  # type: ignore[attr-defined]
-                if item != "!DH"
-            )
-            if value:
-                default_ciphers.append("!DH")
-            urllib3_util_ssl.DEFAULT_CIPHERS = ":".join(default_ciphers)  # type: ignore[attr-defined]
-
-        elif key == "http-ssl-cert":
-            self.http.cert = value
-
-        elif key == "http-timeout":
-            self.http.timeout = value
-
-        # deprecated: {dash,hls}-segment-attempts
-        elif key in ("dash-segment-attempts", "hls-segment-attempts"):
-            self.options.set("stream-segment-attempts", int(value))
-        # deprecated: {dash,hls}-segment-threads
-        elif key in ("dash-segment-threads", "hls-segment-threads"):
-            self.options.set("stream-segment-threads", int(value))
-        # deprecated: {dash,hls}-segment-timeout
-        elif key in ("dash-segment-timeout", "hls-segment-timeout"):
-            self.options.set("stream-segment-timeout", float(value))
-        # deprecated: {hls,dash,http-stream}-timeout
-        elif key in ("dash-timeout", "hls-timeout", "http-stream-timeout"):
-            self.options.set("stream-timeout", float(value))
-
-        else:
-            self.options.set(key, value)
-
-    def get_option(self, key: str):
+    def get_option(self, key: str) -> Any:
         """
         Returns the current value of the specified option.
 
         :param key: key of the option
-
         """
 
-        if key == "http-proxy":
-            return self.http.proxies.get("http")
-        elif key == "https-proxy":
-            return self.http.proxies.get("https")
-        elif key == "http-cookies":
-            return self.http.cookies
-        elif key == "http-headers":
-            return self.http.headers
-        elif key == "http-query-params":
-            return self.http.params
-        elif key == "http-trust-env":
-            return self.http.trust_env
-        elif key == "http-ssl-verify":
-            return self.http.verify
-        elif key == "http-ssl-cert":
-            return self.http.cert
-        elif key == "http-timeout":
-            return self.http.timeout
-        else:
-            return self.options.get(key)
+        return self.options.get(key)
 
     def set_plugin_option(self, plugin: str, key: str, value: Any) -> None:
         """
@@ -350,8 +393,8 @@ class Streamlink:
     def resolve_url(
         self,
         url: str,
-        follow_redirect: bool = True
-    ) -> Tuple[Type[Plugin], str]:
+        follow_redirect: bool = True,
+    ) -> Tuple[str, Type[Plugin], str]:
         """
         Attempts to find a plugin that can use this URL.
 
@@ -367,24 +410,27 @@ class Streamlink:
         url = update_scheme("https://", url, force=False)
 
         matcher: Matcher
-        candidate: Optional[Type[Plugin]] = None
+        candidate: Optional[Tuple[str, Type[Plugin]]] = None
         priority = NO_PRIORITY
         for name, plugin in self.plugins.items():
             if plugin.matchers:
                 for matcher in plugin.matchers:
                     if matcher.priority > priority and matcher.pattern.match(url) is not None:
-                        candidate = plugin
+                        candidate = name, plugin
                         priority = matcher.priority
             # TODO: remove deprecated plugin resolver
             elif hasattr(plugin, "can_handle_url") and callable(plugin.can_handle_url) and plugin.can_handle_url(url):
                 prio = plugin.priority(url) if hasattr(plugin, "priority") and callable(plugin.priority) else NORMAL_PRIORITY
                 if prio > priority:
-                    log.info(f"Resolved plugin {name} with deprecated can_handle_url API")
-                    candidate = plugin
+                    warnings.warn(
+                        f"Resolved plugin {name} with deprecated can_handle_url API",
+                        StreamlinkDeprecationWarning,
+                    )
+                    candidate = name, plugin
                     priority = prio
 
         if candidate:
-            return candidate, url
+            return candidate[0], candidate[1], url
 
         if follow_redirect:
             # Attempt to handle a redirect URL
@@ -402,7 +448,7 @@ class Streamlink:
 
         raise NoPluginError
 
-    def resolve_url_no_redirect(self, url: str) -> Tuple[Type[Plugin], str]:
+    def resolve_url_no_redirect(self, url: str) -> Tuple[str, Type[Plugin], str]:
         """
         Attempts to find a plugin that can use this URL.
 
@@ -424,8 +470,8 @@ class Streamlink:
         :return: A :class:`dict` of stream names and :class:`streamlink.stream.Stream` instances
         """
 
-        pluginclass, resolved_url = self.resolve_url(url)
-        plugin = pluginclass(resolved_url)
+        pluginname, pluginclass, resolved_url = self.resolve_url(url)
+        plugin = pluginclass(self, resolved_url)
 
         return plugin.streams(**params)
 
@@ -446,9 +492,9 @@ class Streamlink:
         """
 
         success = False
-        user_input_requester = self.get_option("user-input-requester")
         for loader, name, ispkg in pkgutil.iter_modules([path]):
             # set the full plugin module name
+            # use the "streamlink.plugins." prefix even for sideloaded plugins
             module_name = f"streamlink.plugins.{name}"
             try:
                 mod = load_module(module_name, path)
@@ -460,10 +506,9 @@ class Streamlink:
                 continue
             success = True
             plugin = mod.__plugin__
-            plugin.bind(self, name, user_input_requester)
-            if plugin.module in self.plugins:
-                log.debug(f"Plugin {plugin.module} is being overridden by {mod.__file__}")
-            self.plugins[plugin.module] = plugin
+            if name in self.plugins:
+                log.debug(f"Plugin {name} is being overridden by {mod.__file__}")
+            self.plugins[name] = plugin
 
         return success
 
