@@ -2,16 +2,16 @@ import copy
 import datetime
 import itertools
 import logging
-import os.path
 from collections import defaultdict
+from contextlib import contextmanager
+from pathlib import Path
+from time import time
+from typing import Dict, Optional
 from urllib.parse import urlparse, urlunparse
 
-import requests
-
 from streamlink import PluginError, StreamError
-from streamlink.stream.dash_manifest import MPD, freeze_timeline, sleep_until, sleeper, utc
+from streamlink.stream.dash_manifest import MPD, Representation, Segment, freeze_timeline, utc
 from streamlink.stream.ffmpegmux import FFMPEGMuxer
-from streamlink.stream.http import normalize_key, valid_args
 from streamlink.stream.segmented import SegmentedStreamReader, SegmentedStreamWorker, SegmentedStreamWriter
 from streamlink.stream.stream import Stream
 from streamlink.utils.l10n import Language
@@ -21,6 +21,13 @@ log = logging.getLogger(__name__)
 
 
 class DASHStreamWriter(SegmentedStreamWriter):
+    reader: "DASHStreamReader"
+    stream: "DASHStream"
+
+    @staticmethod
+    def _get_segment_name(segment: Segment) -> str:
+        return Path(urlparse(segment.url).path).resolve().name
+
     def fetch(self, segment, retries=None):
         if self.closed or not retries:
             return
@@ -31,9 +38,11 @@ class DASHStreamWriter(SegmentedStreamWriter):
             now = datetime.datetime.now(tz=utc)
             if segment.available_at > now:
                 time_to_wait = (segment.available_at - now).total_seconds()
-                fname = os.path.basename(urlparse(segment.url).path)
-                log.debug("Waiting for segment: {fname} ({wait:.01f}s)".format(fname=fname, wait=time_to_wait))
-                sleep_until(segment.available_at)
+                fname = self._get_segment_name(segment)
+                log.debug(f"Waiting for segment: {fname} ({time_to_wait:.01f}s)")
+                if not self.wait(time_to_wait):
+                    log.debug(f"Waiting for segment: {fname} aborted")
+                    return
 
             if segment.range:
                 start, length = segment.range
@@ -41,7 +50,7 @@ class DASHStreamWriter(SegmentedStreamWriter):
                     end = start + length - 1
                 else:
                     end = ""
-                headers["Range"] = "bytes={0}-{1}".format(start, end)
+                headers["Range"] = f"bytes={start}-{end}"
 
             return self.session.http.get(segment.url,
                                          timeout=self.timeout,
@@ -53,22 +62,37 @@ class DASHStreamWriter(SegmentedStreamWriter):
             return self.fetch(segment, retries - 1)
 
     def write(self, segment, res, chunk_size=8192):
+        name = self._get_segment_name(segment)
         for chunk in res.iter_content(chunk_size):
-            if not self.closed:
-                self.reader.buffer.write(chunk)
-            else:
-                log.warning("Download of segment: {} aborted".format(segment.url))
+            if self.closed:
+                log.warning(f"Download of segment: {name} aborted")
                 return
+            self.reader.buffer.write(chunk)
 
-        log.debug("Download of segment: {} complete".format(segment.url))
+        log.debug(f"Download of segment: {name} complete")
 
 
 class DASHStreamWorker(SegmentedStreamWorker):
+    reader: "DASHStreamReader"
+    writer: "DASHStreamWriter"
+    stream: "DASHStream"
+
     def __init__(self, *args, **kwargs):
-        SegmentedStreamWorker.__init__(self, *args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.mpd = self.stream.mpd
         self.period = self.stream.period
 
+    @contextmanager
+    def sleeper(self, duration):
+        """
+        Do something and then wait for a given duration minus the time it took doing something
+        """
+        s = time()
+        yield
+        time_to_sleep = duration - (time() - s)
+        if time_to_sleep > 0:
+            self.wait(time_to_sleep)
+
     @staticmethod
     def get_representation(mpd, representation_id, mime_type):
         for aset in mpd.periods[0].adaptationSets:
@@ -82,28 +106,35 @@ class DASHStreamWorker(SegmentedStreamWorker):
         while not self.closed:
             # find the representation by ID
             representation = self.get_representation(self.mpd, self.reader.representation_id, self.reader.mime_type)
-            refresh_wait = max(self.mpd.minimumUpdatePeriod.total_seconds(),
-                               self.mpd.periods[0].duration.total_seconds()) or 5
 
             if self.mpd.type == "static":
                 refresh_wait = 5
+            else:
+                refresh_wait = max(
+                    self.mpd.minimumUpdatePeriod.total_seconds(),
+                    self.mpd.periods[0].duration.total_seconds(),
+                ) or 5
 
-            with sleeper(refresh_wait * back_off_factor):
-                if representation:
-                    for segment in representation.segments(init=init):
-                        if self.closed:
-                            break
-                        yield segment
-                        # log.debug(f"Adding segment {segment.url} to queue")
+            with self.sleeper(refresh_wait * back_off_factor):
+                if not representation:
+                    continue
 
-                    if self.mpd.type == "dynamic":
-                        if not self.reload():
-                            back_off_factor = max(back_off_factor * 1.3, 10.0)
-                        else:
-                            back_off_factor = 1
-                    else:
-                        return
-                    init = False
+                for segment in representation.segments(init=init):
+                    if self.closed:
+                        break
+                    yield segment
+
+                # close worker if type is not dynamic (all segments were put into writer queue)
+                if self.mpd.type != "dynamic":
+                    self.close()
+                    return
+
+                if not self.reload():
+                    back_off_factor = max(back_off_factor * 1.3, 10.0)
+                else:
+                    back_off_factor = 1
+
+                init = False
 
     def reload(self):
         if self.closed:
@@ -132,23 +163,42 @@ class DASHStreamReader(SegmentedStreamReader):
     __worker__ = DASHStreamWorker
     __writer__ = DASHStreamWriter
 
-    def __init__(self, stream, representation_id, mime_type, *args, **kwargs):
-        SegmentedStreamReader.__init__(self, stream, *args, **kwargs)
+    worker: "DASHStreamWorker"
+    writer: "DASHStreamWriter"
+    stream: "DASHStream"
+
+    def __init__(self, stream: "DASHStream", representation_id, mime_type, *args, **kwargs):
+        super().__init__(stream, *args, **kwargs)
         self.mime_type = mime_type
         self.representation_id = representation_id
         log.debug("Opening DASH reader for: {0} ({1})".format(self.representation_id, self.mime_type))
 
 
 class DASHStream(Stream):
+    """
+    Implementation of the "Dynamic Adaptive Streaming over HTTP" protocol (MPEG-DASH)
+    """
+
     __shortname__ = "dash"
 
-    def __init__(self,
-                 session,
-                 mpd,
-                 video_representation=None,
-                 audio_representation=None,
-                 period=0,
-                 **args):
+    def __init__(
+        self,
+        session,
+        mpd: MPD,
+        video_representation: Optional[Representation] = None,
+        audio_representation: Optional[Representation] = None,
+        period: float = 0,
+        **args
+    ):
+        """
+        :param streamlink.Streamlink session: Streamlink session instance
+        :param mpd: Parsed MPD manifest
+        :param video_representation: Video representation
+        :param audio_representation: Audio representation
+        :param period: Update period
+        :param args: Additional keyword arguments passed to :meth:`requests.Session.request`
+        """
+
         super().__init__(session)
         self.mpd = mpd
         self.video_representation = video_representation
@@ -157,26 +207,46 @@ class DASHStream(Stream):
         self.args = args
 
     def __json__(self):
-        req = requests.Request(method="GET", url=self.mpd.url, **valid_args(self.args))
-        req = req.prepare()
+        json = dict(type=self.shortname())
 
-        headers = dict(map(normalize_key, req.headers.items()))
-        return dict(type=type(self).shortname(), url=req.url, headers=headers)
+        if self.mpd.url:
+            args = self.args.copy()
+            args.update(url=self.mpd.url)
+            req = self.session.http.prepare_new_request(**args)
+            json.update(
+                # the MPD URL has already been prepared by the initial request in `parse_manifest`
+                url=self.mpd.url,
+                headers=dict(req.headers),
+            )
+
+        return json
+
+    def to_url(self):
+        if self.mpd.url is None:
+            return super().to_url()
+
+        # the MPD URL has already been prepared by the initial request in `parse_manifest`
+        return self.mpd.url
 
     @classmethod
-    def parse_manifest(cls, session, url_or_manifest, **args):
+    def parse_manifest(
+        cls,
+        session,
+        url_or_manifest: str,
+        **args
+    ) -> Dict[str, "DASHStream"]:
         """
-        Attempt to parse a DASH manifest file and return its streams
+        Parse a DASH manifest file and return its streams.
 
-        :param session: Streamlink session instance
+        :param streamlink.Streamlink session: Streamlink session instance
         :param url_or_manifest: URL of the manifest file or an XML manifest string
-        :return: a dict of name -> DASHStream instances
+        :param args: Additional keyword arguments passed to :meth:`requests.Session.request`
         """
 
         if url_or_manifest.startswith('<?xml'):
             mpd = MPD(parse_xml(url_or_manifest, ignore_ns=True))
         else:
-            res = session.http.get(url_or_manifest, **args)
+            res = session.http.get(url_or_manifest, **session.http.valid_request_args(**args))
             url = res.url
 
             urlp = list(urlparse(url))
@@ -246,9 +316,22 @@ class DASHStream(Stream):
         for k, v in ret:
             dict_value_list[k].append(v)
 
+        def sortby_bandwidth(dash_stream: DASHStream) -> int:
+            if dash_stream.video_representation:
+                return dash_stream.video_representation.bandwidth
+            if dash_stream.audio_representation:
+                return dash_stream.audio_representation.bandwidth
+            return 0  # pragma: no cover
+
         ret_new = {}
         for q in dict_value_list:
             items = dict_value_list[q]
+
+            try:
+                items = sorted(items, key=sortby_bandwidth, reverse=True)
+            except AttributeError:
+                pass
+
             for n in range(len(items)):
                 if n == 0:
                     ret_new[q] = items[n]
@@ -273,9 +356,3 @@ class DASHStream(Stream):
             return video
         elif self.audio_representation:
             return audio
-
-    def to_url(self):
-        return self.mpd.url
-
-    def to_manifest_url(self):
-        return self.mpd.url
