@@ -8,6 +8,7 @@ import requests_mock
 
 from streamlink import Streamlink
 from streamlink.stream.hls import HLSStream, HLSStreamWriter as _HLSStreamWriter
+from tests.testutils.handshake import Handshake
 
 
 TIMEOUT_AWAIT_READ = 5
@@ -91,9 +92,7 @@ class Segment(HLSItemBase):
 class EventedHLSStreamWriter(_HLSStreamWriter):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.write_wait = Event()
-        self.write_done = Event()
-        self.write_error = None
+        self.handshake = Handshake()
 
     def _futures_put(self, item):
         self.futures.put_nowait(item)
@@ -107,19 +106,12 @@ class EventedHLSStreamWriter(_HLSStreamWriter):
 
     def write(self, *args, **kwargs):
         # only write once per step
-        self.write_wait.wait()
-        self.write_wait.clear()
-
-        try:
+        with self.handshake(Exception) as cm:
             # don't write again during teardown
             if not self.closed:
                 super().write(*args, **kwargs)
-        except Exception as err:  # pragma: no cover
-            self.write_error = err
+        if cm.error:  # pragma: no cover
             self.reader.close()
-        finally:
-            # notify main thread that writing has finished
-            self.write_done.set()
 
 
 class HLSStreamReadThread(Thread):
@@ -129,12 +121,10 @@ class HLSStreamReadThread(Thread):
     def __init__(self, session: Streamlink, stream: HLSStream, *args, **kwargs):
         super().__init__(*args, **kwargs, daemon=True)
 
-        self.read_wait = Event()
         self.read_once = Event()
-        self.read_done = Event()
+        self.handshake = Handshake()
         self.read_all = False
         self.data: List[bytes] = []
-        self.error = None
 
         self.session = session
         self.stream = stream
@@ -154,10 +144,7 @@ class HLSStreamReadThread(Thread):
             # at least one read was attempted
             self.read_once.set()
             # only read once per step
-            self.read_wait.wait()
-            self.read_wait.clear()
-
-            try:
+            with self.handshake(OSError) as cm:
                 # don't read again during teardown
                 # if there is data left, close() was called manually, and it needs to be read
                 if self.reader.buffer.closed and self.reader.buffer.length == 0:
@@ -168,21 +155,18 @@ class HLSStreamReadThread(Thread):
                     return
 
                 self.data.append(self.reader.read(-1))
-            except OSError as err:
-                self.error = err
+
+            if cm.error:
                 return
-            finally:
-                # notify main thread that reading has finished
-                self.read_done.set()
 
     def reset(self):
-        self.data[:] = []
-        self.error = None
+        self.data.clear()
 
     def close(self):
         self.reader.buffer.close()
         self.read_once.set()
-        self.read_wait.set()
+        # allow reader thread to terminate
+        self.handshake.go()
 
 
 class TestMixinStreamHLS(unittest.TestCase):
@@ -239,39 +223,24 @@ class TestMixinStreamHLS(unittest.TestCase):
         self.assertTrue(self.thread.reader.closed, "Stream reader is closed")
 
     # make write calls on the write-thread and wait until it has finished
-    def await_write(self, write_calls=1, timeout=TIMEOUT_AWAIT_WRITE):
-        writer = self.thread.reader.writer
-        if not writer.is_alive():  # pragma: no cover
-            raise RuntimeError("Write thread is not alive")
-
+    def await_write(self, write_calls=1, timeout=TIMEOUT_AWAIT_WRITE) -> None:
+        writer: EventedHLSStreamWriter = self.thread.reader.writer  # type: ignore[assignment]
+        assert writer.is_alive()
         for write_call in range(write_calls):
-            writer.write_wait.set()
-            done = writer.write_done.wait(timeout)
-            if writer.write_error:  # pragma: no cover
-                raise writer.write_error
-            if not done:  # pragma: no cover
-                raise RuntimeError(f"Await write timeout: write_call={write_call + 1}")
-            writer.write_done.clear()
+            assert writer.handshake.step(timeout)
 
     # make one read call on the read thread and wait until it has finished
     def await_read(self, read_all=False, timeout=TIMEOUT_AWAIT_READ):
         thread = self.thread
-        if not thread.is_alive():  # pragma: no cover
-            raise RuntimeError("Read thread is not alive")
-
         thread.read_all = read_all
-        thread.read_wait.set()
-        done = thread.read_done.wait(timeout)
 
-        try:
-            if thread.error:  # pragma: no cover
-                raise thread.error
-            if not done:  # pragma: no cover
-                raise RuntimeError(f"Await read timeout: read_all={read_all}")
-            return b"".join(thread.data)
-        finally:
-            thread.read_done.clear()
-            thread.reset()
+        assert thread.is_alive()
+        assert thread.handshake.step(timeout)
+
+        data = b"".join(thread.data)
+        thread.reset()
+
+        return data
 
     def get_session(self, options=None, *args, **kwargs):
         return Streamlink(options)
@@ -302,6 +271,7 @@ class TestMixinStreamHLS(unittest.TestCase):
     def close(self):
         thread = self.thread
         thread.reader.close()
+        # Allow writer and reader threads to terminate
         if isinstance(thread.reader.writer, EventedHLSStreamWriter):
-            thread.reader.writer.write_wait.set()
-        thread.read_wait.set()
+            thread.reader.writer.handshake.go()
+        thread.handshake.go()
