@@ -5,10 +5,10 @@ from tests.plugins import PluginCanHandleUrl
 class TestPluginCanHandleUrlDailyMotion(PluginCanHandleUrl):
     __plugin__ = DailyMotion
 
-    should_match = [
-        "https://www.dailymotion.com/video/xigbvx",
-        "https://www.dailymotion.com/france24",
-        "https://www.dailymotion.com/embed/video/xigbvx",
+    should_match_groups = [
+        ("https://www.dailymotion.com/france24", {"user": "france24"}),
+        ("https://www.dailymotion.com/video/x8dmdzz", {"media_id": "x8dmdzz"}),
+        ("https://www.dailymotion.com/embed/video/x8dmdzz", {"media_id": "x8dmdzz"}),
     ]
 
     should_not_match = [
