@@ -22,7 +22,8 @@ class TestPluginFunimationNow(unittest.TestCase):
         from streamlink_cli.main import setup_plugin_args
         session = Streamlink()
         parser = MagicMock()
-        group = parser.add_argument_group("Plugin Options").add_argument_group("FunimationNow")
+        plugins = parser.add_argument_group("Plugin Options")
+        group = parser.add_argument_group("FunimationNow", parent=plugins)
 
         session.plugins = {
             'funimationnow': FunimationNow
