@@ -29,44 +29,49 @@ class TestPluginCanHandleUrlVK(PluginCanHandleUrl):
     ]
 
 
-@pytest.mark.parametrize("url,newurl,raises", [
+@pytest.mark.parametrize("url,newurl", [
     # canonical video URL
-    ("https://vk.com/video-24136539_456241176",
-     "https://vk.com/video-24136539_456241176",
-     False),
+    pytest.param(
+        "https://vk.com/video-24136539_456241176",
+        "https://vk.com/video-24136539_456241176",
+    ),
 
     # video ID from URL
-    ("https://vk.com/videos-24136539?z=video-24136539_456241181%2Fpl_-24136539_-2",
-     "https://vk.com/video-24136539_456241181",
-     False),
-    ("https://vk.com/videos132886594?z=video132886594_167211693",
-     "https://vk.com/video132886594_167211693",
-     False),
-    ("https://vk.com/search?c%5Bq%5D=dota&c%5Bsection%5D=auto&z=video295508334_171402661",
-     "https://vk.com/video295508334_171402661",
-     False),
+    pytest.param(
+        "https://vk.com/videos-24136539?z=video-24136539_456241181%2Fpl_-24136539_-2",
+        "https://vk.com/video-24136539_456241181",
+    ),
+    pytest.param(
+        "https://vk.com/videos132886594?z=video132886594_167211693",
+        "https://vk.com/video132886594_167211693",
+    ),
+    pytest.param(
+        "https://vk.com/search?c%5Bq%5D=dota&c%5Bsection%5D=auto&z=video295508334_171402661",
+        "https://vk.com/video295508334_171402661",
+    ),
 
     # video ID from HTTP request
-    ("https://vk.com/dota2?w=wall-126093223_1057924",
-     "https://vk.com/video-126093223_1057924",
-     False),
+    pytest.param(
+        "https://vk.com/dota2?w=wall-126093223_1057924",
+        "https://vk.com/video-126093223_1057924",
+    ),
 
     # no video ID
-    ("https://vk.com/videos-0123456789?z=",
-     "",
-     True),
-    ("https://vk.com/video/for_kids?z=video%2Fpl_-22277933_51053000",
-     "",
-     True),
+    pytest.param(
+        "https://vk.com/videos-0123456789?z=",
+        "",
+        marks=pytest.mark.xfail(raises=NoStreamsError),
+    ),
+    pytest.param(
+        "https://vk.com/video/for_kids?z=video%2Fpl_-22277933_51053000",
+        "",
+        marks=pytest.mark.xfail(raises=NoStreamsError),
+    ),
 ])
-def test_url_redirect(url, newurl, raises, requests_mock):
+def test_url_redirect(url: str, newurl: str, requests_mock):
     session = Streamlink()
-    plugin = VK(session, url)
+    plugin: VK = VK(session, url)
     requests_mock.register_uri(rm.ANY, rm.ANY, exc=rm.exceptions.InvalidRequest)
     requests_mock.get(url, text=f"""<!DOCTYPE html><html><head><meta property="og:url" content="{newurl}"/></head></html>""")
-    try:
-        plugin.follow_vk_redirect()
-        assert not raises
-        assert plugin.url == newurl
-    except NoStreamsError:
-        assert raises
+    plugin.follow_vk_redirect()
+    assert plugin.url == newurl
