@@ -21,7 +21,7 @@ def _parse_xml(data, strip_ns=False):
     except Exception as err:  # pragma: no cover
         snippet = repr(data)
         if len(snippet) > 35:
-            snippet = snippet[:35] + " ..."
+            snippet = f"{snippet[:35]} ..."
 
         raise ValueError("Unable to parse XML: {0} ({1})".format(err, snippet))
 
